import { __decorate } from 'tslib';
import { EventEmitter, Input, Output, ViewChild, Component, forwardRef, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { fromTextArea } from 'codemirror';
import { CommonModule } from '@angular/common';

var LtCodemirrorComponent_1;
/**
 * CodeMirror component
 * Usage :
 * <lt-codemirror [(ngModel)]="data" [config]="{...}"></lt-codemirror>
 */
let LtCodemirrorComponent = LtCodemirrorComponent_1 = class LtCodemirrorComponent {
    /**
     * Constructor
     */
    constructor() {
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
        this.blur = new EventEmitter();
        this.cursorActivity = new EventEmitter();
        this.instance = null;
        this.val = '';
    }
    get value() { return this.val; }
    set value(v) {
        if (v !== this.val) {
            this.val = v;
            this.onChange(v);
        }
    }
    /**
     * On component destroy
     */
    ngOnDestroy() {
    }
    /**
     * On component view init
     */
    ngAfterViewInit() {
        this.config = this.config || {};
        this.codemirrorInit(this.config, this.size);
    }
    /**
     * Initialize codemirror
     */
    codemirrorInit(config, size) {
        this.instance = fromTextArea(this.host.nativeElement, config);
        this.instance.setValue(this.val);
        this.instance.on('change', () => {
            this.updateValue(this.instance.getValue());
        });
        this.instance.on('focus', (instance, event) => {
            this.focus.emit({ instance, event });
        });
        this.instance.on('cursorActivity', (instance) => {
            this.cursorActivity.emit({ instance });
        });
        this.instance.on('blur', (instance, event) => {
            this.blur.emit({ instance, event });
        });
        if (this.size != undefined) {
            this.instance.setSize(this.size.w, this.size.h);
        }
    }
    /**
     * Value update process
     */
    updateValue(value) {
        this.value = value;
        this.onTouched();
        this.change.emit(value);
    }
    /**
     * Implements ControlValueAccessor
     */
    writeValue(value) {
        this.val = value || '';
        if (this.instance) {
            this.instance.setValue(this.val);
        }
    }
    onChange(_) { }
    onTouched() { }
    registerOnChange(fn) { this.onChange = fn; }
    registerOnTouched(fn) { this.onTouched = fn; }
};
__decorate([
    Input()
], LtCodemirrorComponent.prototype, "config", void 0);
__decorate([
    Input()
], LtCodemirrorComponent.prototype, "size", void 0);
__decorate([
    Output()
], LtCodemirrorComponent.prototype, "change", void 0);
__decorate([
    Output()
], LtCodemirrorComponent.prototype, "focus", void 0);
__decorate([
    Output()
], LtCodemirrorComponent.prototype, "blur", void 0);
__decorate([
    Output()
], LtCodemirrorComponent.prototype, "cursorActivity", void 0);
__decorate([
    ViewChild('host', { static: false })
], LtCodemirrorComponent.prototype, "host", void 0);
__decorate([
    Output()
], LtCodemirrorComponent.prototype, "instance", void 0);
__decorate([
    Input()
], LtCodemirrorComponent.prototype, "value", null);
LtCodemirrorComponent = LtCodemirrorComponent_1 = __decorate([
    Component({
        selector: 'lt-codemirror',
        providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => LtCodemirrorComponent_1),
                multi: true
            }
        ],
        template: `
    <textarea #host></textarea>
`
    })
], LtCodemirrorComponent);

let LtCodemirrorModule = class LtCodemirrorModule {
};
LtCodemirrorModule = __decorate([
    NgModule({
        imports: [
            CommonModule
        ],
        declarations: [LtCodemirrorComponent],
        exports: [LtCodemirrorComponent]
    })
], LtCodemirrorModule);

/*
 * Public API Surface of lt-codemirror
 */

/**
 * Generated bundle index. Do not edit.
 */

export { LtCodemirrorComponent, LtCodemirrorModule };
//# sourceMappingURL=lt-codemirror.js.map
