import { __decorate } from 'tslib';
import { EventEmitter, Input, Output, ViewChild, Component, forwardRef, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { fromTextArea } from 'codemirror';
import { CommonModule } from '@angular/common';

/**
 * CodeMirror component
 * Usage :
 * <lt-codemirror [(ngModel)]="data" [config]="{...}"></lt-codemirror>
 */
var LtCodemirrorComponent = /** @class */ (function () {
    /**
     * Constructor
     */
    function LtCodemirrorComponent() {
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
        this.blur = new EventEmitter();
        this.cursorActivity = new EventEmitter();
        this.instance = null;
        this.val = '';
    }
    LtCodemirrorComponent_1 = LtCodemirrorComponent;
    Object.defineProperty(LtCodemirrorComponent.prototype, "value", {
        get: function () { return this.val; },
        set: function (v) {
            if (v !== this.val) {
                this.val = v;
                this.onChange(v);
            }
        },
        enumerable: true,
        configurable: true
    });
    /**
     * On component destroy
     */
    LtCodemirrorComponent.prototype.ngOnDestroy = function () {
    };
    /**
     * On component view init
     */
    LtCodemirrorComponent.prototype.ngAfterViewInit = function () {
        this.config = this.config || {};
        this.codemirrorInit(this.config, this.size);
    };
    /**
     * Initialize codemirror
     */
    LtCodemirrorComponent.prototype.codemirrorInit = function (config, size) {
        var _this = this;
        this.instance = fromTextArea(this.host.nativeElement, config);
        this.instance.setValue(this.val);
        this.instance.on('change', function () {
            _this.updateValue(_this.instance.getValue());
        });
        this.instance.on('focus', function (instance, event) {
            _this.focus.emit({ instance: instance, event: event });
        });
        this.instance.on('cursorActivity', function (instance) {
            _this.cursorActivity.emit({ instance: instance });
        });
        this.instance.on('blur', function (instance, event) {
            _this.blur.emit({ instance: instance, event: event });
        });
        if (this.size != undefined) {
            this.instance.setSize(this.size.w, this.size.h);
        }
    };
    /**
     * Value update process
     */
    LtCodemirrorComponent.prototype.updateValue = function (value) {
        this.value = value;
        this.onTouched();
        this.change.emit(value);
    };
    /**
     * Implements ControlValueAccessor
     */
    LtCodemirrorComponent.prototype.writeValue = function (value) {
        this.val = value || '';
        if (this.instance) {
            this.instance.setValue(this.val);
        }
    };
    LtCodemirrorComponent.prototype.onChange = function (_) { };
    LtCodemirrorComponent.prototype.onTouched = function () { };
    LtCodemirrorComponent.prototype.registerOnChange = function (fn) { this.onChange = fn; };
    LtCodemirrorComponent.prototype.registerOnTouched = function (fn) { this.onTouched = fn; };
    var LtCodemirrorComponent_1;
    __decorate([
        Input()
    ], LtCodemirrorComponent.prototype, "config", void 0);
    __decorate([
        Input()
    ], LtCodemirrorComponent.prototype, "size", void 0);
    __decorate([
        Output()
    ], LtCodemirrorComponent.prototype, "change", void 0);
    __decorate([
        Output()
    ], LtCodemirrorComponent.prototype, "focus", void 0);
    __decorate([
        Output()
    ], LtCodemirrorComponent.prototype, "blur", void 0);
    __decorate([
        Output()
    ], LtCodemirrorComponent.prototype, "cursorActivity", void 0);
    __decorate([
        ViewChild('host', { static: false })
    ], LtCodemirrorComponent.prototype, "host", void 0);
    __decorate([
        Output()
    ], LtCodemirrorComponent.prototype, "instance", void 0);
    __decorate([
        Input()
    ], LtCodemirrorComponent.prototype, "value", null);
    LtCodemirrorComponent = LtCodemirrorComponent_1 = __decorate([
        Component({
            selector: 'lt-codemirror',
            providers: [
                {
                    provide: NG_VALUE_ACCESSOR,
                    useExisting: forwardRef(function () { return LtCodemirrorComponent_1; }),
                    multi: true
                }
            ],
            template: "\n    <textarea #host></textarea>\n"
        })
    ], LtCodemirrorComponent);
    return LtCodemirrorComponent;
}());

var LtCodemirrorModule = /** @class */ (function () {
    function LtCodemirrorModule() {
    }
    LtCodemirrorModule = __decorate([
        NgModule({
            imports: [
                CommonModule
            ],
            declarations: [LtCodemirrorComponent],
            exports: [LtCodemirrorComponent]
        })
    ], LtCodemirrorModule);
    return LtCodemirrorModule;
}());

/*
 * Public API Surface of lt-codemirror
 */

/**
 * Generated bundle index. Do not edit.
 */

export { LtCodemirrorComponent, LtCodemirrorModule };
//# sourceMappingURL=lt-codemirror.js.map
